@@ -47,3 +47,9 @@ GOFLAGS="${OLDGOFLAGS}"
 
 # Make sure our dependencies are up-to-date
 ${REPO_ROOT_DIR}/hack/update-deps.sh
+
+# Make sure the OpenAPI specification and Swagger file are up-to-date
+${REPO_ROOT_DIR}/hack/update-openapigen.sh
+
+# Make sure the API reference docs are up-to-date
+${REPO_ROOT_DIR}/hack/update-reference-docs.sh
